@@ -61,9 +61,10 @@ class Video(ABC):
 
         if self.verbose:
             print(f'Dimensions: {self.width}x{self.height}')
-            print(f'scale Factor: {self.scale}')
+            print(f'Scale Factor: {self.scale}')
             print(f'Scaled Dims: {self.scaled_width}x{self.scaled_height}')
             print(f'Gradient: \'{self.gradient}\'')
+            print(f'FPS: {self.fps}')
 
     def convert(self):  # function which is called to populate the list of converted frames (self.frames)
         if self.verbose: print('Converting...')
